summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit267cf798d949a1783157e09cdb78e1a796b9507b (patch)
tree979a5099909a758256369527c6f867816c4ec9c5
parent23a5fcb7bcfc9b701a351706d3ea99b274c3127d (diff)
downloadkrename-267cf798.tar.gz
krename-267cf798.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/krename@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
-rw-r--r--krename/ProgressDialog.cpp4
-rw-r--r--krename/ProgressDialog.h2
-rw-r--r--krename/confdialog.cpp4
-rw-r--r--krename/confdialog.h2
-rw-r--r--krename/coorddialog.cpp12
-rw-r--r--krename/coorddialog.h2
-rw-r--r--krename/dsdirselectdialog.cpp4
-rw-r--r--krename/dsdirselectdialog.h2
-rw-r--r--krename/firststartdlg.cpp4
-rw-r--r--krename/firststartdlg.h2
-rw-r--r--krename/helpdialog.cpp4
-rw-r--r--krename/helpdialog.h2
-rw-r--r--krename/kmyhistorycombo.cpp4
-rw-r--r--krename/kmyhistorycombo.h2
-rw-r--r--krename/kmylistbox.cpp4
-rw-r--r--krename/kmylistbox.h2
-rw-r--r--krename/kmylistview.cpp36
-rw-r--r--krename/kmylistview.h18
-rw-r--r--krename/krecursivelister.cpp2
-rw-r--r--krename/krecursivelister.h2
-rw-r--r--krename/krenameimpl.cpp116
-rw-r--r--krename/krenameimpl.h4
-rw-r--r--krename/myinputdialog.cpp4
-rw-r--r--krename/myinputdialog.h2
-rw-r--r--krename/numberdialog.cpp4
-rw-r--r--krename/numberdialog.h6
-rw-r--r--krename/permission.cpp4
-rw-r--r--krename/profiledlg.cpp8
-rw-r--r--krename/profiledlg.h2
-rw-r--r--krename/replacedialog.cpp4
-rw-r--r--krename/replacedialog.h2
-rw-r--r--krename/tabs.cpp4
-rw-r--r--krename/tabs.h2
-rw-r--r--krename/undodialog.cpp4
-rw-r--r--krename/undodialog.h2
-rw-r--r--krename/wizard.cpp4
-rw-r--r--krename/wizard.h2
37 files changed, 144 insertions, 144 deletions
diff --git a/krename/ProgressDialog.cpp b/krename/ProgressDialog.cpp
index 91110e6..99b601f 100644
--- a/krename/ProgressDialog.cpp
+++ b/krename/ProgressDialog.cpp
@@ -44,8 +44,8 @@
// update user interface every 1/2 second
#define TIMER_INTERVAL 500
-ProgressDialog::ProgressDialog( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+ProgressDialog::ProgressDialog( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
renamedFiles = NULL;
diff --git a/krename/ProgressDialog.h b/krename/ProgressDialog.h
index 2b467b0..9f9985d 100644
--- a/krename/ProgressDialog.h
+++ b/krename/ProgressDialog.h
@@ -46,7 +46,7 @@ class ProgressDialog : public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- ProgressDialog( TQWidget* tqparent = 0, const char* name = 0, WFlags fl = 0 );
+ ProgressDialog( TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
~ProgressDialog();
void setProgressTotalSteps( int t );
diff --git a/krename/confdialog.cpp b/krename/confdialog.cpp
index 871f498..985cc43 100644
--- a/krename/confdialog.cpp
+++ b/krename/confdialog.cpp
@@ -29,9 +29,9 @@
#include <kiconloader.h>
#include <klocale.h>
-ConfDialog::ConfDialog( TQWidget* tqparent, const char* name )
+ConfDialog::ConfDialog( TQWidget* parent, const char* name )
: KDialogBase( KDialogBase::IconList, "KRename",
- KDialogBase::Ok | KDialogBase::Cancel | KDialogBase::Default, KDialogBase::Ok, tqparent, name, true, true ),
+ KDialogBase::Ok | KDialogBase::Cancel | KDialogBase::Default, KDialogBase::Ok, parent, name, true, true ),
GUIModeSelector()
{
setupTab1();
diff --git a/krename/confdialog.h b/krename/confdialog.h
index f4a4aeb..937ed08 100644
--- a/krename/confdialog.h
+++ b/krename/confdialog.h
@@ -35,7 +35,7 @@ class ConfDialog : public KDialogBase, public GUIModeSelector {
Q_OBJECT
TQ_OBJECT
public:
- ConfDialog( TQWidget* tqparent = 0, const char* name = 0 );
+ ConfDialog( TQWidget* parent = 0, const char* name = 0 );
~ConfDialog();
inline bool loadplugins() const { return checkPlugins->isChecked(); }
diff --git a/krename/coorddialog.cpp b/krename/coorddialog.cpp
index 48d5955..f76996e 100644
--- a/krename/coorddialog.cpp
+++ b/krename/coorddialog.cpp
@@ -28,8 +28,8 @@
#include <kapplication.h>
#include <klocale.h>
-DSLineEdit::DSLineEdit( TQWidget* tqparent, const char* name )
- : KLineEdit( tqparent, name )
+DSLineEdit::DSLineEdit( TQWidget* parent, const char* name )
+ : KLineEdit( parent, name )
{
}
@@ -51,14 +51,14 @@ CoordDialog::CoordDialog( const TQString & file, TQWidget *_parent, const char *
: KDialogBase( KDialogBase::Plain, "KRename",
KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, _parent, name, true, true ), m_file( file )
{
- TQFrame* tqparent = plainPage();
- TQVBoxLayout* tqlayout = new TQVBoxLayout( tqparent );
+ TQFrame* parent = plainPage();
+ TQVBoxLayout* tqlayout = new TQVBoxLayout( parent );
- filename = new DSLineEdit( tqparent );
+ filename = new DSLineEdit( parent );
filename->setText( file );
filename->setValidator( new TQRegExpValidator( TQRegExp( file ), TQT_TQOBJECT(this) ) );
- preview = new TQLabel( tqparent );
+ preview = new TQLabel( parent );
checkInvert = new TQCheckBox( i18n("&Invert selection"), plainPage() );
checkInvert->setChecked( m_inversion );
diff --git a/krename/coorddialog.h b/krename/coorddialog.h
index fe5e298..5ef70b0 100644
--- a/krename/coorddialog.h
+++ b/krename/coorddialog.h
@@ -26,7 +26,7 @@ class DSLineEdit : public KLineEdit {
Q_OBJECT
TQ_OBJECT
public:
- DSLineEdit( TQWidget* tqparent = 0, const char* name = 0 );
+ DSLineEdit( TQWidget* parent = 0, const char* name = 0 );
signals:
void changed();
diff --git a/krename/dsdirselectdialog.cpp b/krename/dsdirselectdialog.cpp
index 2051e7d..621003e 100644
--- a/krename/dsdirselectdialog.cpp
+++ b/krename/dsdirselectdialog.cpp
@@ -30,8 +30,8 @@
#include <klocale.h>
#include <kurlcombobox.h>
-DSDirSelectDialog::DSDirSelectDialog( TQWidget* tqparent )
- : KFileDialog( ":KRename", "*", tqparent, 0, false )
+DSDirSelectDialog::DSDirSelectDialog( TQWidget* parent )
+ : KFileDialog( ":KRename", "*", parent, 0, false )
{
setOperationMode( KFileDialog::Opening );
setMode( KFile::Files | KFile::ExistingOnly );
diff --git a/krename/dsdirselectdialog.h b/krename/dsdirselectdialog.h
index 66cd3ba..1bb9aad 100644
--- a/krename/dsdirselectdialog.h
+++ b/krename/dsdirselectdialog.h
@@ -30,7 +30,7 @@ class DSDirSelectDialog : public KFileDialog {
TQ_OBJECT
public:
- DSDirSelectDialog( TQWidget* tqparent );
+ DSDirSelectDialog( TQWidget* parent );
bool recursively() const;
bool hidden() const;
diff --git a/krename/firststartdlg.cpp b/krename/firststartdlg.cpp
index 928d74c..e500c7f 100644
--- a/krename/firststartdlg.cpp
+++ b/krename/firststartdlg.cpp
@@ -17,9 +17,9 @@
#include "firststartdlg.h"
-FirstStartDlg::FirstStartDlg(TQWidget *tqparent, const char *name )
+FirstStartDlg::FirstStartDlg(TQWidget *parent, const char *name )
: KDialogBase( KDialogBase::Plain, "KRename",
- KDialogBase::Ok, KDialogBase::Ok, tqparent, name, true, true ),
+ KDialogBase::Ok, KDialogBase::Ok, parent, name, true, true ),
GUIModeSelector()
{
setCaption( guiModeCaption() );
diff --git a/krename/firststartdlg.h b/krename/firststartdlg.h
index 422c69a..b96032f 100644
--- a/krename/firststartdlg.h
+++ b/krename/firststartdlg.h
@@ -26,7 +26,7 @@ class FirstStartDlg : public KDialogBase, public GUIModeSelector {
Q_OBJECT
TQ_OBJECT
public:
- FirstStartDlg(TQWidget *tqparent=0, const char *name=0);
+ FirstStartDlg(TQWidget *parent=0, const char *name=0);
~FirstStartDlg();
};
diff --git a/krename/helpdialog.cpp b/krename/helpdialog.cpp
index 9f0a57f..fe42ef3 100644
--- a/krename/helpdialog.cpp
+++ b/krename/helpdialog.cpp
@@ -64,9 +64,9 @@ TQStringList HelpDialogData::tokens() const
}
-HelpDialog::HelpDialog( HelpDialogData* data, TQWidget* tqparent,
+HelpDialog::HelpDialog( HelpDialogData* data, TQWidget* parent,
const char* name, bool modal, WFlags fl )
- : TQDialog( tqparent, name, modal, fl )
+ : TQDialog( parent, name, modal, fl )
{
text = NULL;
diff --git a/krename/helpdialog.h b/krename/helpdialog.h
index 4e97916..055c59e 100644
--- a/krename/helpdialog.h
+++ b/krename/helpdialog.h
@@ -77,7 +77,7 @@ class HelpDialog : public TQDialog
Q_OBJECT
TQ_OBJECT
public:
- HelpDialog( HelpDialogData* data, TQWidget* tqparent = 0,
+ HelpDialog( HelpDialogData* data, TQWidget* parent = 0,
const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
~HelpDialog();
diff --git a/krename/kmyhistorycombo.cpp b/krename/kmyhistorycombo.cpp
index c9409ed..e1c8b22 100644
--- a/krename/kmyhistorycombo.cpp
+++ b/krename/kmyhistorycombo.cpp
@@ -36,8 +36,8 @@
#define KRENAME_NUMBER 5003
#define KRENAME_DATE 5004
-KMyHistoryCombo::KMyHistoryCombo( bool customPopup, TQWidget* tqparent, const char* name)
- : KHistoryCombo(tqparent, name)
+KMyHistoryCombo::KMyHistoryCombo( bool customPopup, TQWidget* parent, const char* name)
+ : KHistoryCombo(parent, name)
{
TQStringList history;
TQStringList completion;
diff --git a/krename/kmyhistorycombo.h b/krename/kmyhistorycombo.h
index b28d516..dfe30ac 100644
--- a/krename/kmyhistorycombo.h
+++ b/krename/kmyhistorycombo.h
@@ -34,7 +34,7 @@ class KMyHistoryCombo : public KHistoryCombo {
*
* \param customPopup insert custom menu items into context menu.
*/
- KMyHistoryCombo(bool customPopup, TQWidget* tqparent=0, const char* name=0);
+ KMyHistoryCombo(bool customPopup, TQWidget* parent=0, const char* name=0);
~KMyHistoryCombo();
/**
diff --git a/krename/kmylistbox.cpp b/krename/kmylistbox.cpp
index 873ba93..716cb30 100644
--- a/krename/kmylistbox.cpp
+++ b/krename/kmylistbox.cpp
@@ -43,8 +43,8 @@
using namespace KIO;
-KMyListBox::KMyListBox(TQWidget* tqparent, const char* name, WFlags fl)
- :KListBox(tqparent, name, fl)
+KMyListBox::KMyListBox(TQWidget* parent, const char* name, WFlags fl)
+ :KListBox(parent, name, fl)
{
m_running_lister_counter = 0;
diff --git a/krename/kmylistbox.h b/krename/kmylistbox.h
index 4a90cf4..65d36b0 100644
--- a/krename/kmylistbox.h
+++ b/krename/kmylistbox.h
@@ -41,7 +41,7 @@ class KMyListBox : public KListBox {
public:
enum { ASCENDING = 1, DESCENDING = 2, RANDOM = 3, NUMMERIC = 4, UNSORTED = 0 };
- KMyListBox(TQWidget* tqparent=0, const char* name=0, WFlags fl=0);
+ KMyListBox(TQWidget* parent=0, const char* name=0, WFlags fl=0);
~KMyListBox();
void removeItem( int index );
diff --git a/krename/kmylistview.cpp b/krename/kmylistview.cpp
index 079cb7b..976e8d3 100644
--- a/krename/kmylistview.cpp
+++ b/krename/kmylistview.cpp
@@ -24,8 +24,8 @@
#include <kpopupmenu.h>
#include <krun.h>
-KMyListView::KMyListView( TQValueList<manualchanges>* _changes, KMyListBox* _list, TQWidget* tqparent, const char* name )
- :KListView(tqparent, name )
+KMyListView::KMyListView( TQValueList<manualchanges>* _changes, KMyListBox* _list, TQWidget* parent, const char* name )
+ :KListView(parent, name )
{
changes = _changes;
list = _list;
@@ -114,50 +114,50 @@ void KMyListView::openCurrent()
/////////////////////////////////////////////////////////////
-KMyListViewItem::KMyListViewItem(TQListView *tqparent)
- : KListViewItem(tqparent)
+KMyListViewItem::KMyListViewItem(TQListView *parent)
+ : KListViewItem(parent)
{ }
-KMyListViewItem::KMyListViewItem(TQListViewItem *tqparent)
- : KListViewItem(tqparent)
+KMyListViewItem::KMyListViewItem(TQListViewItem *parent)
+ : KListViewItem(parent)
{ }
-KMyListViewItem::KMyListViewItem(TQListView *tqparent, TQListViewItem *after)
- : KListViewItem(tqparent, after)
+KMyListViewItem::KMyListViewItem(TQListView *parent, TQListViewItem *after)
+ : KListViewItem(parent, after)
{ }
-KMyListViewItem::KMyListViewItem(TQListViewItem *tqparent, TQListViewItem *after)
- : KListViewItem(tqparent, after)
+KMyListViewItem::KMyListViewItem(TQListViewItem *parent, TQListViewItem *after)
+ : KListViewItem(parent, after)
{ }
-KMyListViewItem::KMyListViewItem(bool m, TQListView *tqparent,
+KMyListViewItem::KMyListViewItem(bool m, TQListView *parent,
TQString label1, TQString label2, TQString label3, TQString label4,
TQString label5, TQString label6, TQString label7, TQString label8)
- : KListViewItem(tqparent, label1, label2, label3, label4, label5, label6, label7, label8)
+ : KListViewItem(parent, label1, label2, label3, label4, label5, label6, label7, label8)
{
modified = m;
}
-KMyListViewItem::KMyListViewItem(bool m, TQListViewItem *tqparent,
+KMyListViewItem::KMyListViewItem(bool m, TQListViewItem *parent,
TQString label1, TQString label2, TQString label3, TQString label4,
TQString label5, TQString label6, TQString label7, TQString label8)
- : KListViewItem(tqparent, label1, label2, label3, label4, label5, label6, label7, label8)
+ : KListViewItem(parent, label1, label2, label3, label4, label5, label6, label7, label8)
{
modified = m;
}
-KMyListViewItem::KMyListViewItem(bool m, TQListView *tqparent, TQListViewItem *after,
+KMyListViewItem::KMyListViewItem(bool m, TQListView *parent, TQListViewItem *after,
TQString label1, TQString label2, TQString label3, TQString label4,
TQString label5, TQString label6, TQString label7, TQString label8)
- : KListViewItem(tqparent, after, label1, label2, label3, label4, label5, label6, label7, label8)
+ : KListViewItem(parent, after, label1, label2, label3, label4, label5, label6, label7, label8)
{
modified = m;
}
-KMyListViewItem::KMyListViewItem(TQListViewItem *tqparent, TQListViewItem *after,
+KMyListViewItem::KMyListViewItem(TQListViewItem *parent, TQListViewItem *after,
TQString label1, TQString label2, TQString label3, TQString label4,
TQString label5, TQString label6, TQString label7, TQString label8)
- : KListViewItem(tqparent, after, label1, label2, label3, label4, label5, label6, label7, label8)
+ : KListViewItem(parent, after, label1, label2, label3, label4, label5, label6, label7, label8)
{ }
KMyListViewItem::~KMyListViewItem()
diff --git a/krename/kmylistview.h b/krename/kmylistview.h
index bcb0973..f694589 100644
--- a/krename/kmylistview.h
+++ b/krename/kmylistview.h
@@ -28,7 +28,7 @@ class KMyListView : public KListView {
Q_OBJECT
TQ_OBJECT
public:
- KMyListView( TQValueList<manualchanges>* _changes, KMyListBox* _list, TQWidget* tqparent=0, const char* name=0 );
+ KMyListView( TQValueList<manualchanges>* _changes, KMyListBox* _list, TQWidget* parent=0, const char* name=0 );
~KMyListView();
signals:
@@ -54,30 +54,30 @@ class TQColor;
class TQString;
class KMyListViewItem : public KListViewItem {
public:
- KMyListViewItem(TQListView *tqparent);
- KMyListViewItem(TQListViewItem *tqparent);
- KMyListViewItem(TQListView *tqparent, TQListViewItem *after);
- KMyListViewItem(TQListViewItem *tqparent, TQListViewItem *after);
+ KMyListViewItem(TQListView *parent);
+ KMyListViewItem(TQListViewItem *parent);
+ KMyListViewItem(TQListView *parent, TQListViewItem *after);
+ KMyListViewItem(TQListViewItem *parent, TQListViewItem *after);
- KMyListViewItem(bool m, TQListView *tqparent,
+ KMyListViewItem(bool m, TQListView *parent,
TQString, TQString = TQString(),
TQString = TQString(), TQString = TQString(),
TQString = TQString(), TQString = TQString(),
TQString = TQString(), TQString = TQString());
- KMyListViewItem(bool m, TQListViewItem *tqparent,
+ KMyListViewItem(bool m, TQListViewItem *parent,
TQString, TQString = TQString(),
TQString = TQString(), TQString = TQString(),
TQString = TQString(), TQString = TQString(),
TQString = TQString(), TQString = TQString());
- KMyListViewItem(bool m, TQListView *tqparent, TQListViewItem *after,
+ KMyListViewItem(bool m, TQListView *parent, TQListViewItem *after,
TQString, TQString = TQString(),
TQString = TQString(), TQString = TQString(),
TQString = TQString(), TQString = TQString(),
TQString = TQString(), TQString = TQString());
- KMyListViewItem(TQListViewItem *tqparent, TQListViewItem *after,
+ KMyListViewItem(TQListViewItem *parent, TQListViewItem *after,
TQString, TQString = TQString(),
TQString = TQString(), TQString = TQString(),
TQString = TQString(), TQString = TQString(),
diff --git a/krename/krecursivelister.cpp b/krename/krecursivelister.cpp
index 17843d0..ac3528d 100644
--- a/krename/krecursivelister.cpp
+++ b/krename/krecursivelister.cpp
@@ -19,7 +19,7 @@
#include "krecursivelister.h"
-KRecursiveLister::KRecursiveLister(TQObject *tqparent, const char *name ) : TQObject(tqparent,name) {
+KRecursiveLister::KRecursiveLister(TQObject *parent, const char *name ) : TQObject(parent,name) {
lister = 0L;
filelist.clear();
dirlist.clear();
diff --git a/krename/krecursivelister.h b/krename/krecursivelister.h
index b676ddb..3c63d86 100644
--- a/krename/krecursivelister.h
+++ b/krename/krecursivelister.h
@@ -37,7 +37,7 @@ class KRecursiveLister : public TQObject {
TQ_OBJECT
public:
- KRecursiveLister(TQObject *tqparent=0, const char *name=0);
+ KRecursiveLister(TQObject *parent=0, const char *name=0);
~KRecursiveLister();
/** Returns the list of fileitems found. */
diff --git a/krename/krenameimpl.h b/krename/krenameimpl.h
index 45bf350..aa8850f 100644
--- a/krename/krenameimpl.h
+++ b/krename/krenameimpl.h
@@ -59,7 +59,7 @@ class TQVGroupBox;
class TQWidget;
#include <kguiitem.h>
-KPushButton* createButton( KGuiItem item, TQWidget* tqparent );
+KPushButton* createButton( KGuiItem item, TQWidget* parent );
class KRenameImpl : public TQObject, public KRenameDCOP {
Q_OBJECT
@@ -195,7 +195,7 @@ class KRenameImpl : public TQObject, public KRenameDCOP {
void getHelpDialogString( TQLineEdit* edit );
protected:
- TQWidget* tqparent;
+ TQWidget* parent;
KMenuBar* menuBar;
KPopupMenu* mnuSort;
KAction* loadPlugins;
diff --git a/krename/myinputdialog.cpp b/krename/myinputdialog.cpp
index f922bb5..38b42bc 100644
--- a/krename/myinputdialog.cpp
+++ b/krename/myinputdialog.cpp
@@ -24,8 +24,8 @@
#include <tqlayout.h>
#include <tqtooltip.h>
-MyInputDialog::MyInputDialog( TQString filename, bool revertEnabled, TQWidget* tqparent )
- : TQDialog( tqparent, 0, true, 0 )
+MyInputDialog::MyInputDialog( TQString filename, bool revertEnabled, TQWidget* parent )
+ : TQDialog( parent, 0, true, 0 )
{
// I do not think this has to be translated
setCaption( "KRename" );
diff --git a/krename/myinputdialog.h b/krename/myinputdialog.h
index 240d26a..f7705e6 100644
--- a/krename/myinputdialog.h
+++ b/krename/myinputdialog.h
@@ -32,7 +32,7 @@ class MyInputDialog : public TQDialog
Q_OBJECT
TQ_OBJECT
public:
- MyInputDialog( TQString filename, bool revertEnabled = true, TQWidget* tqparent = 0 );
+ MyInputDialog( TQString filename, bool revertEnabled = true, TQWidget* parent = 0 );
~MyInputDialog();
TQString filename() const;
diff --git a/krename/numberdialog.cpp b/krename/numberdialog.cpp
index 0e3f327..14151b3 100644
--- a/krename/numberdialog.cpp
+++ b/krename/numberdialog.cpp
@@ -36,9 +36,9 @@ void KMyIntSpinBox::keyPressEvent( TQKeyEvent* e )
emit returnPressed();
}
-NumberDialog::NumberDialog(TQValueList<int> & n,TQWidget *tqparent )
+NumberDialog::NumberDialog(TQValueList<int> & n,TQWidget *parent )
: KDialogBase( KDialogBase::Plain, "KRename",
- KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, tqparent, 0, true, true )
+ KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, parent, 0, true, true )
{
TQSpacerItem* spacer = new TQSpacerItem( 20, 20, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
diff --git a/krename/numberdialog.h b/krename/numberdialog.h
index e4f3adf..260e799 100644
--- a/krename/numberdialog.h
+++ b/krename/numberdialog.h
@@ -30,8 +30,8 @@ class KMyIntSpinBox : public KIntSpinBox
Q_OBJECT
TQ_OBJECT
public:
- KMyIntSpinBox( TQWidget* tqparent )
- : KIntSpinBox( tqparent )
+ KMyIntSpinBox( TQWidget* parent )
+ : KIntSpinBox( parent )
{ };
~KMyIntSpinBox() { };
private:
@@ -48,7 +48,7 @@ class NumberDialog : public KDialogBase {
Q_OBJECT
TQ_OBJECT
public:
- NumberDialog(TQValueList<int> & n,TQWidget *tqparent=0);
+ NumberDialog(TQValueList<int> & n,TQWidget *parent=0);
~NumberDialog();
// TODO: bad object oriented design!!!
diff --git a/krename/permission.cpp b/krename/permission.cpp
index d25a5b6..84a1382 100644
--- a/krename/permission.cpp
+++ b/krename/permission.cpp
@@ -268,7 +268,7 @@ int MyPermPlugin::getPermissions()
{S_IROTH, S_IWOTH, S_IXOTH, S_ISVTX}
};
- int permissions = 0, tqmask = 0;
+ int permissions = 0, mask = 0;
for (int row = 0;row < 3; ++row)
for (int col = 0; col < 4; ++col)
@@ -279,7 +279,7 @@ int MyPermPlugin::getPermissions()
permissions |= fperm[row][col];
//fall through
case TQCheckBox::Off:
- tqmask |= fperm[row][col];
+ mask |= fperm[row][col];
break;
default:
break;
diff --git a/krename/profiledlg.cpp b/krename/profiledlg.cpp
index b917606..c6aef81 100644
--- a/krename/profiledlg.cpp
+++ b/krename/profiledlg.cpp
@@ -391,9 +391,9 @@ void ProfileManager::loadProfile( const TQString & name, KRenameImpl* krename )
///////////////////////////////////////////////////////////////////////////////
-ProfileDlg::ProfileDlg(KRenameImpl* krename, TQWidget *tqparent, const char *name)
+ProfileDlg::ProfileDlg(KRenameImpl* krename, TQWidget *parent, const char *name)
: KDialogBase( KDialogBase::Plain, i18n("Profiles"),
- KDialogBase::Close, KDialogBase::Close, tqparent, name, true, true ), ProfileManager( krename )
+ KDialogBase::Close, KDialogBase::Close, parent, name, true, true ), ProfileManager( krename )
{
int i;
@@ -525,9 +525,9 @@ void ProfileDlg::slotLoadProfile()
void ProfileDlg::slotCreateProfile()
{
bool ok = false;
- const char* tqmask = "xXXXXXXXXXXXXXXXXXXX"; // allows for 20 characters
+ const char* mask = "xXXXXXXXXXXXXXXXXXXX"; // allows for 20 characters
TQString name = KInputDialog::getText( i18n("Profile Name"), i18n("Please enter a name for the new profile:"),
- "KRename", &ok, this, 0, 0, tqmask );
+ "KRename", &ok, this, 0, 0, mask );
if( !ok )
return;
diff --git a/krename/profiledlg.h b/krename/profiledlg.h
index 84280ed..ac1ebe0 100644
--- a/krename/profiledlg.h
+++ b/krename/profiledlg.h
@@ -57,7 +57,7 @@ class ProfileDlg : public KDialogBase, public ProfileManager
TQ_OBJECT
public:
- ProfileDlg(KRenameImpl* krename, TQWidget *tqparent = 0, const char *name = 0);
+ ProfileDlg(KRenameImpl* krename, TQWidget *parent = 0, const char *name = 0);
~ProfileDlg();
private slots:
diff --git a/krename/replacedialog.cpp b/krename/replacedialog.cpp
index f48be78..68435e2 100644
--- a/krename/replacedialog.cpp
+++ b/krename/replacedialog.cpp
@@ -35,9 +35,9 @@
#include <kpushbutton.h>
#include <kregexpeditorinterface.h>
-ReplaceDialog::ReplaceDialog( TQValueList<replacestrings> & r, TQWidget* tqparent )
+ReplaceDialog::ReplaceDialog( TQValueList<replacestrings> & r, TQWidget* parent )
: KDialogBase( KDialogBase::Plain, i18n( "Find and Replace" ),
- KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, tqparent, 0, true, true )
+ KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, parent, 0, true, true )
{
ReplaceDialogLayout = new TQGridLayout( plainPage(), 11, 6);
diff --git a/krename/replacedialog.h b/krename/replacedialog.h
index 13d7542..d550b7e 100644
--- a/krename/replacedialog.h
+++ b/krename/replacedialog.h
@@ -39,7 +39,7 @@ class ReplaceDialog : public KDialogBase
TQ_OBJECT
public:
- ReplaceDialog( TQValueList<replacestrings> & r, TQWidget* tqparent = 0 );
+ ReplaceDialog( TQValueList<replacestrings> & r, TQWidget* parent = 0 );
~ReplaceDialog();
TQValueList<replacestrings> getList();
diff --git a/krename/tabs.cpp b/krename/tabs.cpp
index bb3543a..d10ee26 100644
--- a/krename/tabs.cpp
+++ b/krename/tabs.cpp
@@ -33,8 +33,8 @@
#include <kpushbutton.h>
#include <kstartupinfo.h>
-tabs::tabs(KRenameImpl* impl, TQRect r, TQWidget *tqparent, const char *name )
- : TQDialog(tqparent,name)
+tabs::tabs(KRenameImpl* impl, TQRect r, TQWidget *parent, const char *name )
+ : TQDialog(parent,name)
{
setIcon( BarIcon( "krename" ) );
diff --git a/krename/tabs.h b/krename/tabs.h
index 0c23b7f..e7fed0f 100644
--- a/krename/tabs.h
+++ b/krename/tabs.h
@@ -32,7 +32,7 @@ class tabs : public TQDialog {
Q_OBJECT
TQ_OBJECT
public:
- tabs(KRenameImpl* impl, TQRect r, TQWidget *tqparent=0, const char *name=0);
+ tabs(KRenameImpl* impl, TQRect r, TQWidget *parent=0, const char *name=0);
~tabs();
inline KRenameImpl* getKRename() { return krename; }
diff --git a/krename/undodialog.cpp b/krename/undodialog.cpp
index d5b549b..487a154 100644
--- a/krename/undodialog.cpp
+++ b/krename/undodialog.cpp
@@ -29,9 +29,9 @@
#include <ktextbrowser.h>
#include <kurlrequester.h>
-UndoDialog::UndoDialog( TQWidget* tqparent )
+UndoDialog::UndoDialog( TQWidget* parent )
: KDialogBase( KDialogBase::Plain, i18n("Undo Renaming"),
- KDialogBase::User1 | KDialogBase::Close, KDialogBase::User1, tqparent, 0, false, true )
+ KDialogBase::User1 | KDialogBase::Close, KDialogBase::User1, parent, 0, false, true )
{
UndoDialogLayout = new TQVBoxLayout( plainPage(), 11, 6, "UndoDialogLayout");
diff --git a/krename/undodialog.h b/krename/undodialog.h
index 6cdea12..b325e82 100644
--- a/krename/undodialog.h
+++ b/krename/undodialog.h
@@ -33,7 +33,7 @@ class UndoDialog : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- UndoDialog( TQWidget* tqparent = 0 );
+ UndoDialog( TQWidget* parent = 0 );
~UndoDialog();
void setUndoScript( const TQString & filename );
diff --git a/krename/wizard.cpp b/krename/wizard.cpp
index 6d2c690..09a9d09 100644
--- a/krename/wizard.cpp
+++ b/krename/wizard.cpp
@@ -34,8 +34,8 @@
#include <tqsizepolicy.h>
#include <tqvbox.h>
-wizard::wizard( KRenameImpl* impl, TQRect r, TQWidget* tqparent, const char* name )
- : KWizard( tqparent, name )
+wizard::wizard( KRenameImpl* impl, TQRect r, TQWidget* parent, const char* name )
+ : KWizard( parent, name )
{
setIcon( BarIcon( "krename" ) );
menuBar = new KMenuBar(this);
diff --git a/krename/wizard.h b/krename/wizard.h
index 8ca06da..6619157 100644
--- a/krename/wizard.h
+++ b/krename/wizard.h
@@ -35,7 +35,7 @@ class wizard : public KWizard
TQ_OBJECT
public:
- wizard( KRenameImpl* impl, TQRect r, TQWidget* tqparent = 0, const char* name = 0 );
+ wizard( KRenameImpl* impl, TQRect r, TQWidget* parent = 0, const char* name = 0 );
~wizard();
inline KRenameImpl* getKRename() { return krename; }
diff --git a/krename/krenameimpl.cpp b/krename/krenameimpl.cpp
index befaa79..42736e7 100644
--- a/krename/krenameimpl.cpp
+++ b/krename/krenameimpl.cpp
@@ -83,21 +83,21 @@ TQString pageTitle[] = {
I18N_NOOP( "File&name" )
};
-KPushButton* createButton( KGuiItem item, TQWidget* tqparent )
+KPushButton* createButton( KGuiItem item, TQWidget* parent )
{
- return new KPushButton( item.iconSet(), item.text(), tqparent );
+ return new KPushButton( item.iconSet(), item.text(), parent );
}
KRenameImpl::KRenameImpl( TQWidget* p, KMenuBar* m, TQPushButton* finish )
: DCOPObject( "KRename" ), TQObject( (TQObject*)p ),
- tqparent( p ), menuBar( m ), finishButton( finish )
+ parent( p ), menuBar( m ), finishButton( finish )
{
m_hasCommandlineProfile = false;
// Load Plugins
plugin = PluginLoader::instance();
helpDialogData = new HelpDialogData();
// Maybe tqparent instead of 0 but might crash when switching from wizard to tab mode
helpDialog = new HelpDialog( helpDialogData, NULL, NULL, false );
m_switching = false;
@@ -115,7 +115,7 @@ int KRenameImpl::numRealTimePreview = -1;
void KRenameImpl::setup( bool wizardmode )
{
- tqparent->setCaption( "KRename" ); // "KRename by Dominik Seichter
+ parent->setCaption( "KRename" ); // "KRename by Dominik Seichter
setupActions();
setupPages();
updateCount();
@@ -295,9 +295,9 @@ void KRenameImpl::setupActions()
{
KActionCollection* actionCollection = new KActionCollection( this );
- KPopupMenu* mnuExtra = new KPopupMenu( tqparent );
- KPopupMenu* mnuSettings = new KPopupMenu( tqparent );
- KHelpMenu* mnuHelp = new KHelpMenu( tqparent );
+ KPopupMenu* mnuExtra = new KPopupMenu( parent );
+ KPopupMenu* mnuSettings = new KPopupMenu( parent );
+ KHelpMenu* mnuHelp = new KHelpMenu( parent );
menuBar->insertItem( i18n("E&xtras"), mnuExtra );
mnuExtra->insertItem( i18n("&Profiles..."), this, TQT_SLOT( manageProfiles() ) );
@@ -332,7 +332,7 @@ void KRenameImpl::setupPages()
void KRenameImpl::setupPage1()
{
- page_1 = new TQWidget( tqparent );
+ page_1 = new TQWidget( parent );
pageLayout = new TQHBoxLayout( page_1, 11, 6 );
Layout3 = new TQVBoxLayout( 0, 0, 6 );
@@ -414,7 +414,7 @@ void KRenameImpl::setupPage1()
void KRenameImpl::setupPage2()
{
- page_2 = new TQWidget( tqparent );
+ page_2 = new TQWidget( parent );
pageLayout_2 = new TQVBoxLayout( page_2, 6, 6 );
@@ -481,7 +481,7 @@ void KRenameImpl::setupPage2()
void KRenameImpl::setupPage3()
{
- page_3 = new KJanusWidget( tqparent, "janus", KJanusWidget::TreeList );
+ page_3 = new KJanusWidget( parent, "janus", KJanusWidget::TreeList );
page_3->setShowIconsInTreeList( true );
page_3->setTreeListAutoResize( true );
@@ -492,7 +492,7 @@ void KRenameImpl::setupPage3()
void KRenameImpl::setupPage4()
{
- page_4 = new TQWidget( tqparent );
+ page_4 = new TQWidget( parent );
pageLayout_4 = new TQVBoxLayout( page_4, 11, 6 );
fileTab = new TQWidgetStack( page_4 );
@@ -587,7 +587,7 @@ void KRenameImpl::setupFileTab1()
help.append("[$x-y];;" + i18n("character x to y of old filename") );
help.append("[$x;y];;" + i18n("y characters of old filename starting at x") );
help.append("[$dirname];;" + i18n("insert name of directory") );
- help.append("[$dirname.];;" + i18n("insert name of tqparent directory") );
+ help.append("[$dirname.];;" + i18n("insert name of parent directory") );
help.append("[#length-0];;" + i18n("insert the length of the input filename") );
helpDialogData->add( i18n("Built-in Functions:" ), &help, SmallIcon("krename"), true );
@@ -875,7 +875,7 @@ void KRenameImpl::setupTab1()
* Draw plugin user interfaces
*/
- TQFrame* tqparent;
+ TQFrame* parent;
TQVBoxLayout* Layout;
TQVBoxLayout* gLayout;
TQGroupBox* g;
@@ -892,13 +892,13 @@ void KRenameImpl::setupTab1()
while ( it.current() ) {
if( !(*it)->plugin->alwaysUsed() )
{
- tqparent = page_3->addPage( (*it)->plugin->getName(), TQString(), (*it)->plugin->getIcon() );
+ parent = page_3->addPage( (*it)->plugin->getName(), TQString(), (*it)->plugin->getIcon() );
- Layout = new TQVBoxLayout( tqparent, 11, 6, "Layout");
- g = new TQGroupBox( tqparent );
+ Layout = new TQVBoxLayout( parent, 11, 6, "Layout");
+ g = new TQGroupBox( parent );
gLayout = new TQVBoxLayout( g, 11, 6, "gLayout" );
- (*it)->check = new TQCheckBox( i18n("&Use this plugin"), tqparent );
+ (*it)->check = new TQCheckBox( i18n("&Use this plugin"), parent );
connect( (*it)->check, TQT_SIGNAL( clicked() ), this, TQT_SLOT( pluginHelpChanged() ) );
connect( (*it)->plugin, TQT_SIGNAL( previewChanged( Plugin* ) ), this, TQT_SLOT( updatePluginPreview( Plugin* ) ) );
Layout->addWidget( (*it)->check );
@@ -919,7 +919,7 @@ void KRenameImpl::addFile()
{
bool auto_up = false;
- DSDirSelectDialog* dsd = new DSDirSelectDialog( tqparent );
+ DSDirSelectDialog* dsd = new DSDirSelectDialog( parent );
if( dsd->exec() == TQDialog::Accepted ) {
KURL::List slist = dsd->selectedURLs();
KURL::List::Iterator it = slist.begin();
@@ -1022,12 +1022,12 @@ void KRenameImpl::start()
if( setupBatchRenamer( b, false ) )
{
p->show();
- tqparent->hide();
+ parent->hide();
b->processFiles( p, this );
}
// Memory leak!!! : ??
- //delete tqparent;
+ //delete parent;
}
void KRenameImpl::enableControls()
@@ -1046,16 +1046,16 @@ void KRenameImpl::enableControls()
bool KRenameImpl::checkErrors()
{
if( filename->text().isEmpty() ) {
- KMessageBox::sorry( tqparent, i18n("Specify a template to use for renaming files.") );
+ KMessageBox::sorry( parent, i18n("Specify a template to use for renaming files.") );
return false;
}
if( dirname->text().isEmpty() && !optionRename->isChecked()) {
- KMessageBox::sorry( tqparent, i18n("Please give a destination directory !") );
+ KMessageBox::sorry( parent, i18n("Please give a destination directory !") );
emit showPage( 2 );
return false;
}
if( checkUndoScript->isChecked() && !optionCopy->isChecked() && undorequester->url().isEmpty() ) {
- KMessageBox::sorry( tqparent, i18n("Please give the name of the undo script!") );
+ KMessageBox::sorry( parent, i18n("Please give the name of the undo script!") );
showPage( 2 );
return false;
}
@@ -1164,7 +1164,7 @@ bool KRenameImpl::setupBatchRenamer( BatchRenamer* b, bool preview )
if( !KIO::NetAccess::exists( KURL( url ) ) )
{
- int m = KMessageBox::warningContinueCancel( tqparent, i18n("The directory %1 does not exist. "
+ int m = KMessageBox::warningContinueCancel( parent, i18n("The directory %1 does not exist. "
"KRename will create it for you.").tqarg( url ) );
if( m == KMessageBox::Cancel )
return false;
@@ -1278,12 +1278,12 @@ void KRenameImpl::loadConfig()
CoordDialog::m_inversion = config->readBoolEntry("Inverse", false);
m_wizard = config->readBoolEntry( "GUIWizardMode", true );
- int width = config->readNumEntry( "Width", tqparent->width() );
- int height = config->readNumEntry( "Height", tqparent->height() );
+ int width = config->readNumEntry( "Width", parent->width() );
+ int height = config->readNumEntry( "Height", parent->height() );
if( config->readBoolEntry("Maximized", false ) ) {
- tqparent->showMaximized();
+ parent->showMaximized();
} else {
- tqparent->resize( width, height );
+ parent->resize( width, height );
}
refreshColumnMode();
@@ -1305,7 +1305,7 @@ void KRenameImpl::loadConfig()
checkName->setEnabled( false );
}
- //tqparent->show();
+ //parent->show();
page_1->setEnabled( false );
KApplication::setOverrideCursor( TQt::WaitCursor );
plugin->loadPlugins( m_loadplugins );
@@ -1329,11 +1329,11 @@ void KRenameImpl::saveConfig()
config->writeEntry("firststart", false );
config->writeEntry("ImagePreview", checkPreview->isChecked() );
config->writeEntry("StartIndex", m_index );
- config->writeEntry("Maximized", tqparent->isMaximized() );
- config->writeEntry("Width", tqparent->width() );
- config->writeEntry("Height", tqparent->height() );
- config->writeEntry("XPos", tqparent->x() );
- config->writeEntry("YPos", tqparent->y() );
+ config->writeEntry("Maximized", parent->isMaximized() );
+ config->writeEntry("Width", parent->width() );
+ config->writeEntry("Height", parent->height() );
+ config->writeEntry("XPos", parent->x() );
+ config->writeEntry("YPos", parent->y() );
config->writeEntry("LoadFilePlugins", m_loadplugins );
config->writeEntry("ColumnAutosize", m_autosize );
config->writeEntry("Name", checkName->isChecked() );
@@ -1349,7 +1349,7 @@ void KRenameImpl::saveConfig()
void KRenameImpl::replace()
{
- ReplaceDialog* r = new ReplaceDialog( rep, tqparent );
+ ReplaceDialog* r = new ReplaceDialog( rep, parent );
if( r->exec() == TQDialog::Accepted )
{
rep = r->getList();
@@ -1377,7 +1377,7 @@ void KRenameImpl::toggleName()
void KRenameImpl::preferences()
{
- ConfDialog* cd = new ConfDialog( tqparent, "cd" );
+ ConfDialog* cd = new ConfDialog( parent, "cd" );
cd->setLoadPlugins( m_loadplugins );
cd->setThumbSize( fileList->getPreviewSize() );
cd->setAutosize( m_autosize );
@@ -1414,21 +1414,21 @@ void KRenameImpl::changeGUIMode()
/* GUI Mode was changed by the user */
saveConfig();
- int x = tqparent->x();
- int y = tqparent->y();
- int w = tqparent->width();
- int h = tqparent->height();
+ int x = parent->x();
+ int y = parent->y();
+ int w = parent->width();
+ int h = parent->height();
- TQWidget* oldtqparent = tqparent;
+ TQWidget* oldparent = parent;
TQWidget* krename = KRenameImpl::launch( TQRect( x, y, w, h ), TQStringList(), this, false );
m_switching = true;
- oldtqparent->removeChild( this );
- oldtqparent->hide();
+ oldparent->removeChild( this );
+ oldparent->hide();
krename->insertChild( this );
krename->show();
- oldtqparent->close();
+ oldparent->close();
m_switching = false;
}
@@ -1460,7 +1460,7 @@ void KRenameImpl::moveDown()
void KRenameImpl::undo()
{
- UndoDialog* u = new UndoDialog( tqparent );
+ UndoDialog* u = new UndoDialog( parent );
u->exec();
delete u;
}
@@ -1519,7 +1519,7 @@ void KRenameImpl::getCoordinates()
TQFileInfo fi( name );
TQString extension;
splitFilename( &fi, &name, &extension );
- CoordDialog* cd = new CoordDialog( name, tqparent );
+ CoordDialog* cd = new CoordDialog( name, parent );
if( cd->exec() == TQDialog::Accepted ) {
TQString t = filename->text();
@@ -1588,7 +1588,7 @@ void KRenameImpl::updateHist()
void KRenameImpl::changeNumbers()
{
- NumberDialog* nd = new NumberDialog( skip, tqparent );
+ NumberDialog* nd = new NumberDialog( skip, parent );
nd->spinIndex->setValue( m_index );
nd->spinStep->setValue( m_step );
nd->checkResetCounter->setChecked( m_reset );
@@ -1606,7 +1606,7 @@ void KRenameImpl::changeNumbers()
void KRenameImpl::about()
{
- KAboutApplication * d = new KAboutApplication( kapp->aboutData(), tqparent );
+ KAboutApplication * d = new KAboutApplication( kapp->aboutData(), parent );
d->show();
}
@@ -1633,23 +1633,23 @@ void KRenameImpl::setWizardMode( bool mode )
void KRenameImpl::changeParent( TQWidget* p, KMenuBar* m, TQPushButton* finish, TQRect r )
{
- tqparent = p;
+ parent = p;
menuBar = m;
finishButton = finish;
connect( finishButton, TQT_SIGNAL( clicked()), this, TQT_SLOT( start() ));
if( !r.isNull() ) {
- tqparent->resize( r.size() );
- tqparent->move( r.x(), r.y() );
+ parent->resize( r.size() );
+ parent->move( r.x(), r.y() );
}
setupActions();
- page_1->reparent( tqparent, TQPoint( 0, 0 ) );
- page_2->reparent( tqparent, TQPoint( 0, 0 ) );
- page_3->reparent( tqparent, TQPoint( 0, 0 ) );
- page_4->reparent( tqparent, TQPoint( 0, 0 ) );
+ page_1->reparent( parent, TQPoint( 0, 0 ) );
+ page_2->reparent( parent, TQPoint( 0, 0 ) );
+ page_3->reparent( parent, TQPoint( 0, 0 ) );
+ page_4->reparent( parent, TQPoint( 0, 0 ) );
emit pageDone( page_1, i18n( pageTitle[0] ) );
emit pageDone( page_2, i18n( pageTitle[1] ) );
@@ -1802,13 +1802,13 @@ void KRenameImpl::reloadFilePluginData()
void KRenameImpl::manageProfiles()
{
- ProfileDlg dlg( this, tqparent, "dlg" );
+ ProfileDlg dlg( this, parent, "dlg" );
dlg.exec();
}
void KRenameImpl::getHelpDialogString( TQLineEdit* edit )
{
- HelpDialog hdlg( helpDialogData, tqparent, "hdlg", true );
+ HelpDialog hdlg( helpDialogData, parent, "hdlg", true );
hdlg.setLineEdit( edit );
hdlg.updateHeadline();
hdlg.updateItems();
@@ -83,21 +83,21 @@ TQString pageTitle[] = {
plugin = PluginLoader::instance();
helpDialogData = new HelpDialogData();
- // Maybe tqparent instead of 0 but might crash when switching from wizard to tab mode
+ // Maybe parent instead of 0 but might crash when switching from wizard to tab mode
helpDialog = new HelpDialog( helpDialogData, NULL, NULL, false );
m_switching = false;